# Felindra - Parrot Media Signature Verifier tool

The *felindra* Python module provides both a library and an executable
to verify the authenticity and integrity of any signed photo taken by
an *ANAFI Ai*. The tool can verify photos remotely on a drone by using the
webserver API or offline, by checking a directory and its subdirectories.

For more information, see the *felindra documentation*.

## [Felindra Documentation](https://developer.parrot.com/docs/groundsdk-tools/photo-signature.html#felindra)

## [Parrot developers forums](https://forum.developer.parrot.com/categories)

* **Parrot Anafi Ai:** https://forum.developer.parrot.com/c/anafi-ai/

## Supported platform

* Tested with Python 3.8.10. It should work on newer versions.
